/*****************************************************************
 *
 * $.toc()
 * by rebecca murphey
 * rmurphey gmail com
 *
 * This function is called on its own and takes as an argument
 * a list of selectors with which it will build a table of
 * contents. 
 *
 * The first selector will make up the top level of the TOC;
 * the second selector will make up the second level of the TOC;
 * etc.
 *
 * This function returns a div containing nested unordered lists;
 * each list item is linked to an anchor tag added before the item
 * on the page.
 *
 * usage: $.toc('h1,h2,h3', listType).prependTo('body');
 * luileito: listType can be either "ul" (default) or "ol"
 *
 ************************************************************************/

(function($) {
  
  $.toc = function(tocList, listType) 
  {
    if (typeof listType == 'undefined') { listType = "ul"; }

    $(tocList).addClass('jquery-toc');
    var tocListArray = tocList.split(',');
    // clean
    $.each(tocListArray, function(i,v){ tocListArray[i] = $.trim(v); });

    var elements = $('.jquery-toc');
    $('body').append('<div></div>');
    var $toc = $('body div:last');

    var lastLevel = 1;
    var anchorList = [];

    // create first-order elements
    $toc.append('<'+listType+' class="jquery-toc-1"></'+listType+'>');
    
    elements.each(function() {
      var e = $(this);
      var text = e.text();

      var anchor = text.replace(/[^A-za-z0-9]/g,'-').toLowerCase();

      var z = 0; 

      // add anchor name to matched list elements (i.e.: h1, h2 ...)
      e.before('<a class="anchor" name="' + anchor + '"></a>');

      var level;

      $.each(tocListArray, function(i,v) { 
        if (v.match(' ')) {
          var vArray = v.split(' ');
          var elm = vArray[vArray.length - 1];
        } else { elm = v; }
        
        if (e.is(elm)) { level = i+1; }
      });

      // create N-order elements
      var className = 'jquery-toc-' + level;

      var li = '<li><a href="#' + anchor + '">' + text + '</a></li>';

      if (level == lastLevel) {
        $(listType+'.' + className + ':last', $toc).append(li);
      } else if (level > lastLevel) {
        var parentLevel = level - 1;
        var parentClassName = 'jquery-toc-' + parentLevel;
        $(listType+'.' + parentClassName + ':last', $toc).
          append('<'+listType+' class="' + className + '"></'+listType+'>');
        $(listType+'.' + className + ':last', $toc).append(li);
      } else if (level < lastLevel) {
        $(listType+'.' + className + ':last', $toc).append(li);
      }

      lastLevel = level;

    });

    var list = $(listType+'.jquery-toc-1', $toc);
    $toc.remove();

    return (list);
 }

})(jQuery);
