<?php
require_once 'class.mycvparser.lite.php';
require_once 'functions.php';

/**
 * A class for building CV pages. Lite version.
 * @author Luis Leiva
 * @date 18 Jun 2010
 * @require class.mycvparser.php
 * @require functions.php
 */
class MyCV extends MyCVParser
{
  /** Custom DOM elements in page head. */
  var $DOMElementsHeader;
  /** Custom DOM elements in page body. */
  var $DOMElementsBody;
  /** Custom DOM elements in page footer. */
  var $DOMElementsFooter;
  
  /**
   * Renders the web page. Steps: validation, header, personal info, sections, and footer
   */
  public function render()
  {
    if (!$this->DOM ) {
      print_r( "Failed loading XML." );
      foreach(libxml_get_errors() as $error) {
        print_r( $error->message );
      }
      exit;
    }

    $this->pageStarts();
    
    $this->formatPersonal(); // special node
    $this->formatSectionGroups(); // the rest of sections
    
    $this->pageEnds();
  }

  /**
   * Applies a CSS theme
   * @param $dir  string  directory name, inside themes/ dir
   */
  public function setTheme($dir)
  {
    $this->setFiles("themes", $dir);
  }

  /**
   * Applies a plugin or a set of plugins
   * @param $dirs string  dir(s) name(s), inside plugins/ dir
   */
  public function setPlugins($dirs)
  {
    foreach ($dirs as $dir) {
      $this->setFiles("plugins", $dir);
    }
  }

  /**
   * Load files from a dir and create the correspondent DOM item
   * @param $base string  base directory name, inside root dir
   * @param $dir  string  directory name, inside base dir
   */
  public function setFiles($base, $dir)
  {
    $path = realpath(SYSPATH.'../'.$base.'/'.$dir);
    if ($handle = opendir($path)) {
      while (false !== ($file = readdir($handle))) {
        $ext = file_info($file, "extension");
          switch($ext) {
            case 'css':
              $this->addDOMElement('<link href="'.BASEURL.$base.'/'.$dir.'/'.$file.'" rel="stylesheet" type="text/css" />', "header");
              break;
            case 'js':
              $this->addDOMElement('<script src="'.BASEURL.$base.'/'.$dir.'/'.$file.'" type="text/javascript"></script>', "header");
              break;
            default:
              break;
          }
      }
      closedir($handle);
    }
  }

  /**
   * Low-level function to create DOM elements, either in the header, body, or footer.
   * @param $elm string  HTML contents
   * @param $type string  header, body (default), or footer
   */
  public function addDOMElement($elm, $type)
  {
    if (!$elm) return;

    switch($type) {
      case 'header':
        $arr = &$this->DOMElementsHeader;
        break;
      case 'body':
      default:
        $arr = &$this->DOMElementsBody;
        break;
      case 'footer':
        $arr = &$this->DOMElementsFooter;
        break;
    }

    if (is_array($elm)) {
      foreach ($elm as $value) {
        $arr[] = $value;
      }
    } else {
      $arr[] = $elm;
    }
  }

  /**
   * Inserts page doctype.
   */  
  public function setDocType()
  {
    print_line( '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">' );
    print_line( '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">' );
  }

  /**
   * Inserts page metatags and basic elements.
   */ 
  protected function setBasicHead()
  {
    $h = array(
      // metatags
      '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />',
      '<meta http-equiv="Title" content="'.SITETITLE.'" />',
      '<meta name="Title" content="'.SITETITLE.'" />',
      '<meta name="Author" content="'.SITETITLE.'" />',
      '<meta name="Description" content="'.SITEDESCRIPTION.'" />',
      '<meta name="Keywords" content="'.SITEKEYWORDS.'" />',
      // some tweaks
      '<meta name="Robots" content="index, follow" />',
      '<meta http-equiv="Pragma" content="no-cache" />',
      '<meta http-equiv="Expires" content="-1" />',
      '<meta name="Distribution" content="global" />',

      '<title>'.SITETITLE.'</title>',
      // favicon
      '<link href="'.BASEURL.'favicon.ico" rel="icon" type="image/x-icon" />',
      '<link href="'.BASEURL.'favicon.ico" rel="shortcut icon" type="image/x-icon" />',
      // css
      '<link href="'.BASEURL.'css/base.css" rel="stylesheet" type="text/css"  />',
      '<link href="'.BASEURL.'css/bib.css" rel="stylesheet" type="text/css"  />',
      '<link href="'.BASEURL.'css/ui.css" rel="stylesheet" type="text/css"  />',
      // scripts
      '<script type="text/javascript" src="'.BASEURL.'js/jquery-1.3.2.min.js"></script>',
    );
    foreach ($h as $tag) {
      print_line( $tag );
    }
  }

  /**
   * Inserts doctype + header (+ custom header elements + custom body elements), and opens page body.
   */
  public function pageStarts()
  {
    $this->setDocType();
    print_line( '<head>' );
    $this->setBasicHead();
    if (count($this->DOMElementsHeader) > 0) {
      foreach ($this->DOMElementsHeader as $elm) {
        print_line( $elm );
      }
    }
    print_line( '</head>' );
    print_line( '<body>' );
    print_line( '<div id="global">' );
    if (count($this->DOMElementsBody) > 0) {
      foreach ($this->DOMElementsBody as $elm) {
        print_line( $elm );
      }
    }
  }

  /**
   * Insert footer elements (if available) and closes page body.
   */
  public function pageEnds()
  {
    if (count($this->DOMElementsFooter) > 0) {
      foreach ($this->DOMElementsFooter as $elm) {
        print_line( $elm );
      }
    }
    print_line( '</div><!-- end global -->' );
    print_line( '</body>' );
    print_line( '</html>' );
  }

}
?>
