<?php
require_once 'class.interface.mywidget.php';

/**
 * A class for creating widgets within the MyCV framework.
 * @author Luis Leiva
 * @date 11 Dec 2010
 * @require class.interface.mywidget.php
 */
class MyWidget extends DOMDocument implements IMyWidget
{
  /** DOMDocument instance. */
  protected $sourceDOM;

  /** Widget category. */
  protected $category = "";

  /** Allowed DOM nodes to insert widgets (see class.mycv.php). */
  protected $head   = "head";
  protected $body   = "body";
  protected $nav    = "nav";
  protected $aside  = "aside";
  protected $footer = "footer";

  // each subclass must call the parent constructor at first: parent::__construct($dom)
  public function __construct($dom)
  {
    $this->sourceDOM = $dom;
  }

  public function __toString() {
    return "MyWidget " . $this->category;
  }

  /**
   * A widget can retrieve the category URL for later referencing files, if necessary.
   */
  public function getCategoryUrl()
  {
    return $this->getBaseUrl().'widgets/'.$this->category;
  }

  /**
   * A widget can retrieve the category URL for later referencing files, if necessary.
   */
  public function getBaseUrl()
  {
//    // get site URL
//    $mycv = $this->sourceDOM->getElementsByTagName('mycv');
//    foreach ($mycv as $m) {
//      $url = $m->getAttribute("url");
//      break;
//    }
    // FIXME: Either remove url_get_base() from `sys/functions.php`
    // or add there the `getAttribute()` approach.
    $url = url_get_base();
    // Does base URL have an ending slash?
    // FIXME: URLs should not end in a slash (Unix style)
    // and this method should report a non-ending slash.
    if (substr($url, -1) != '/') {
      $url .= '/';
    }

    return $url;
  }

  /**
   * A widget should return a string after invoking this method.
   */
  protected function create() {
  }

  /**
   * A widget must define a method to load CSS files.
   */
  public function setCss($path, $newest = TRUE) {
    $t = $newest ? '?'.time() : NULL;
    return '<link href="'.$path.$t.'" rel="stylesheet" type="text/css" />';
  }

  /**
   * A widget must define a method to load JS files.
   */
  public function setJs($path, $newest = TRUE) {
    $t = $newest ? '?'.time() : NULL;
    return '<script src="'.$filepath.$t.'" type="text/javascript"></script>';
  }

  /**
   * A widget must define a placement method (head, body (default), nav, or footer).
   */
  public function placeIn($place = "") {
  }

}
?>
