<?php
require_once realpath(dirname(__FILE__).'/../../').'/sys/class.mywidget.php';

/**
 * Base class for adding a Card-based widget (either vCard or hCard, by now).
 * @author Luis Leiva
 * @date 11 Dec 2010
 * @require class.mywidget.php
 */
abstract class Card extends MyWidget
{
  protected $category = "microformats";

  /** Card fields. */
  protected $fields = array();

  /** 
   * Constructor. 
   * @param $dom  DomDocument reference to MyCV instance
   */
  public function __construct(DomDocument $dom)
  {
    parent::__construct($dom);
    $this->getFields();
  }

  protected function create()
  {
    return $this->buildCard();
  }

  abstract public function buildCard();

  public function placeIn($placement = "") 
  {
    return null;
  }

  protected function getFields() 
  {
    $personal = $this->sourceDOM->getElementsByTagName('personal');
    foreach ($personal as $mydata)
    {
      $nodes = $mydata->getElementsByTagName('*');
      foreach ($nodes as $node)
      {
        switch($node->nodeName)
        {
          case 'photo':
            $this->fields['photo'] = $node;
            break;
          case 'name':
            $this->fields['name'] = $node;
            break;
          case 'birthday':
            $this->fields['birthday'] = $node;
            break;
          case 'occupation':
            $this->fields['occupation'] = $node;
            break;
          case 'affiliation':
            $this->fields['affiliation'] = $node;
            break;
          case 'address':
            $this->fields['address'][] = $node;
            break;
          case 'phone':
            $this->fields['phone'][] = $node;
            break;
          case 'email':
            $this->fields['email'][] = $node;
            break;
          case 'webpage':
            $this->fields['webpage'][] = $node;
            break;
          case 'note':
            $this->fields['note'][] = $node;
            break;
          default:
            break;
        }
      }
    }
  }

  protected function getPhotoUrl(DOMElement $node)
  {
    $img = $node->getAttribute('uri');
    if (strpos($img, 'http://') === false) {
      $img = url_get_base().'/'.$img;
    }

    return $img;
  }

  protected function getCleanText($str)
  {
    $content = strip_tags($str);
    $parts = explode(PHP_EOL, $content);
    foreach ($parts as $key => $value) {
      $parts[$key] = trim($value);
      if (empty($parts[$key])) unset($parts[$key]);
    }

    return implode($this->newLine, $parts);
  }

  protected function getCleanEmail(DOMElement $node)
  {
    $emails = array();
    // luileito@{doctor,iti,dsic}.upv.es
    $mail = $node->getAttribute("inbox");
    list($user,$domain) = explode('@', $mail);
    // check multiple-emails: {host1, ..., hostN}
    if (strpos($domain, '{') !== false) {
      $firstdotindomain = strpos($domain, '.');
      $subdomain = substr($domain, $firstdotindomain+1); // do not include the dot (better)
      $lastbracket = strpos($domain, '}');
      $hostlist = substr($domain, 1, $lastbracket-1);
      $hosts = explode(',', $hostlist);
      foreach ($hosts as $host) {
        $emails[] = $user.'@'.$host.'.'.$subdomain;
      }
    } else {
      $emails[] = $mail;
    }

    return $emails;
  }

  protected function getNodeType(DOMElement $node)
  {
    $type = $node->getAttribute("type");
    if (empty($type)) $type = "pref";

    return $type;
  }

}
?>
