<?php
require_once 'class.card.php';

/**
 * A class for adding a hCard widget. See http://en.wikipedia.org/wiki/HCard
 * @author Luis Leiva
 * @date 11 Dec 2010
 * @require class.mywidget.php
 */
class HCard extends Card
{
  protected $newLine = '<br/>';

  /** 
   * Constructor. 
   * @param $dom  DomDocument reference to MyCV instance
   */
  public function __construct(DomDocument $dom)
  {
    parent::__construct($dom);
  }

  public function buildCard()
  {
    // we will reuse $name for page title (without HTML markup)
    $name = $this->formatName($this->fields['name']);

    $card  = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">';
    $card .= '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">';
    $card .= '<head profile="http://www.w3.org/2006/03/hcard">';
    $card .= '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />';
    $card .= '<meta name="Robots" content="noindex, nofollow" />';
    $card .= '<title>Contact details for '. strip_tags($name) .'</title>';
    $card .= '<link href="styles.css" rel="stylesheet" type="text/css" />';
    $card .= '</head>';
    $card .= '<body>';
    $card .= '<div class="vcard">'; // note: hcard is an vcard with semantic HTML
    if (array_key_exists("photo", $this->fields)) {
      $card .= $this->formatPhoto($this->fields['photo']);
    }
    $card .= $name;
    if (array_key_exists("birthday", $this->fields)) {
      $card .= $this->formatBirthday($this->fields['birthday']);
    }
    if (array_key_exists('occupation', $this->fields)) {
      $card .= $this->formatOccupation($this->fields['occupation']);
    }
    if (array_key_exists('affiliation', $this->fields)) {
      $card .= $this->formatAffiliation($this->fields['affiliation']);
    }
    if (array_key_exists('address', $this->fields)) {
      $card .= '<div class="hcard-wrap-adr">';
      foreach ($this->fields['address'] as $node) {
        $card .= $this->formatAddress($node);
      }
      $card .= '</div>';
    }
    if (array_key_exists('phone', $this->fields)) {
      $card .= '<div class="hcard-wrap-tel">';
      foreach ($this->fields['phone'] as $node) {
        $card .= $this->formatPhone($node);
      }
      $card .= '</div>';
    }
    if (array_key_exists('email', $this->fields)) {
      $card .= '<div class="hcard-wrap-email">';
      foreach ($this->fields['email'] as $node) {
        $card .= $this->formatEmail($node);
      }
      $card .= '</div>';
    }
    if (array_key_exists('webpage', $this->fields)) {
      $card .= '<div class="hcard-wrap-url">';
      foreach ($this->fields['webpage'] as $node) {
        $card .= $this->formatWebpage($node);
      }
      $card .= '</div>';
    }
    if (array_key_exists('note', $this->fields)) {
      $card .= '<div class="hcard-wrap-note">';
      foreach ($this->fields['note'] as $node) {
        $card .= $this->formatNote($node);
      }
      $card .= '</div>';
    }
    $card .= '</div><!-- end vcard -->';
    $card .= '</body>';
    $card .= '</html>';

    return $card;
  }

  protected function formatPhoto(DOMElement $node)
  {
    $img = $this->getPhotoUrl($node);
    if (!empty($img)) {
      return '<img class="photo" src="'.$img.'" alt="Photo of '.strip_tags($this->formatName($this->fields['name'])).'" />';
    }
  }

  protected function formatName(DOMElement $node)
  {
    $first = $node->getAttribute("first");
    $middle = $node->getAttribute("middle");
    $last = $node->getAttribute("last");

    $entry  = '<h1 class="fn">';
    $entry .= '<span class="given-name">' . $first .'</span> ';
    if( !empty($middle) ) {
      $entry .= '<span class="additional-name">'. $middle .'.</span> ';
    }
    $entry .= '<span class="family-name">'. $last .'</span>';
    $entry .= '</h1>';

    return $entry;
  }

  protected function formatBirthday(DOMElement $node)
  {
    $year = $node->getAttribute("year");
    if (empty($year)) $year = "0000";
    $month = $node->getAttribute("month");
    if (empty($month)) $month .= '00';
    $day = $node->getAttribute("day");
    if (empty($day)) $day = '00';
    // display month in human-readable format
    $monthstr = date("F", mktime(0,0,0, $month, $day, $year));

    return '<div class="hcard-wrap-bday"><abbr class="bday" title="'.$year.'-'.$month.'-'.$day.'">'.$year.' '.$monthstr.' '.$day.'</abbr></div>';
  }

  protected function formatOccupation(DOMElement $node)
  {
    return '<div class="title">'.$this->getCleanText($node->nodeValue).'</div>';
  }

  protected function formatAffiliation(DOMElement $node)
  {
    return '<div class="org"><span class="organization-name">'.$this->getCleanText($node->nodeValue).'</span></div>';
  }

  protected function formatAddress(DOMElement $node)
  {
    $entry  = '<div class="adr">';
    $entry .= '<small><span class="type">'.$node->getAttribute("type").'</span> address:</small>';
    $entry .= '<div class="street-address">'.$node->getAttribute("street").'</div>';
    $entry .= '<span class="locality">'.$node->getAttribute("city").'</span> ';
    $entry .= '(<span class="region">'.$node->getAttribute("region").'</span>) ';
    $entry .= '<span class="postal-code">'.$node->getAttribute("zip").'</span> ';
    $entry .= '<div class="country-name">'.$node->getAttribute("country").'</div>';
    $entry .= '</div><!-- end adr -->';

    return $entry;
  }

  protected function formatPhone(DOMElement $node)
  {
    $entry  = '<div class="tel '.$this->getNodeType($node).'">';
    $entry .= 'phone ('.$this->getNodeType($node).'): ';
    $entry .= '<a href="tel:'.$node->getAttribute("prefix").$node->getAttribute("number").'">';
    $entry .= '('.$node->getAttribute("prefix").') '.$node->getAttribute("number");
    $entry .= '</a>';
    $entry .= '</div>';

    return $entry;
  }

  protected function formatEmail(DOMElement $node)
  {
    $entry = '';
    $emails = $this->getCleanEmail($node);
    $type = $this->getNodeType($node);
    foreach ($emails as $mail) {
      //$entry .= '<div><a class="email fn '.$type.'" href="mailto:'.$mail.'">'.$type.' email</a></div>';
      $entry .= '<div>email ('.$type.'): <a class="email fn '.$type.'" href="mailto:'.$mail.'">'.str_replace("@", "_AT_", $mail).'</a></div>';
    }

    return $entry;
  }

  protected function formatWebpage(DOMElement $node)
  {
    $type = $this->getNodeType($node);
    $desc = $node->getAttribute("desc");
    $uri = $node->getAttribute("uri");
    if (empty($desc)) $desc = $uri;

    return '<div>web ('.$type.'): <a class="fn url '.$this->getNodeType($node).'" href="'.$uri.'">'.$desc.'</a></div>';
  }

  protected function formatNote(DOMElement $node)
  {
    return '<div class="note">'.$this->getCleanText($node->nodeValue).'</div>';
  }

  protected function getNodeType(DOMElement $node)
  {
    return strtolower( parent::getNodeType($node) );
  }

}
?>
