<?php
require_once 'class.card.php';

/**
 * A class for adding a vCard widget. See http://en.wikipedia.org/wiki/VCard
 * @author Luis Leiva
 * @date 11 Dec 2010
 * @require class.mywidget.php
 */
abstract class VCard extends Card
{
  /** 
   * Constructor. 
   * @param $dom  DomDocument reference to MyCV instance
   */
  public function __construct(DomDocument $dom)
  {
    parent::__construct($dom);
  }

  public function buildCard()
  {
    $card  = 'BEGIN:VCARD' .PHP_EOL;
    $card .= 'VERSION:'. $this->getVersion() .PHP_EOL;
    $card .= $this->formatName($this->fields['name']) .PHP_EOL;
    if (array_key_exists("birthday", $this->fields)) {
      $card .= $this->formatBirthday($this->fields['birthday']) .PHP_EOL;
    }
    if (array_key_exists("affiliation", $this->fields)) {
      $card .= $this->formatAffiliation($this->fields['affiliation']) .PHP_EOL;
    }
    if (array_key_exists("occupation", $this->fields)) {
      $card .= $this->formatOccupation($this->fields['occupation']) .PHP_EOL;
    }
    if (array_key_exists("photo", $this->fields)) {
      $card .= $this->formatPhoto($this->fields['photo']); // only for v3
    }
    if (array_key_exists("phone", $this->fields)) {
      foreach ($this->fields['phone'] as $node) {
        $card .= $this->formatPhone($node);
      }
    }
    if (array_key_exists("address", $this->fields)) {
      foreach ($this->fields['address'] as $node) {
        $card .= $this->formatAddress($node);
      }
    }
    if (array_key_exists("email", $this->fields)) {
      foreach ($this->fields['email'] as $node) {
        $card .= $this->formatEmail($node);
      }
    }
    if (array_key_exists("webpage", $this->fields)) {
      foreach ($this->fields['webpage'] as $node) {
        $card .= $this->formatWebpage($node);
      }
    }
    if (array_key_exists("note", $this->fields)) {
      foreach ($this->fields['note'] as $node) {
        $card .= $this->formatNote($node);
      }
    }
    $card .= 'REV:'.date("Ymd").'T'.date("His").'Z' .PHP_EOL;
    $card .= 'END:VCARD' .PHP_EOL;

    return $card;
  }

  // only available for v3
  abstract protected function formatPhoto(DOMElement $node);

  protected function formatName(DOMElement $node)
  {
    $first = $node->getAttribute("first");
    $middle = $node->getAttribute("middle");
    $last = $node->getAttribute("last");

    $entry = 'N;CHARSET=UTF-8:'. $last .';'. $first;
    if( !empty($middle) ) {
      $entry .= ' '. $middle .'.';
    }

    $entry .= PHP_EOL;

    $entry .= 'FN;CHARSET=UTF-8:' . $first .' ';
    if( !empty($middle) ) {
      $entry .= $middle .'. ';
    }
    $entry .= $last;

    return $entry;
  }

  protected function formatBirthday(DOMElement $node)
  {
    $year = $node->getAttribute("year");
    if (empty($year)) $year = "0000";
    $month = $node->getAttribute("month");
    if (empty($month)) $month .= '00';
    $day = $node->getAttribute("day");
    if (empty($day)) $day = '00';

    return 'BDAY:' . $year.'-'.$month.'-'.$day;

    return 'BDAY:' . $year.$month.$day;
  }

  protected function formatOccupation(DOMElement $node)
  {
    return 'TITLE;CHARSET=UTF-8:'. $this->getCleanText($node->nodeValue);
  }

  protected function formatAffiliation(DOMElement $node)
  {
    return 'ORG;CHARSET=UTF-8:'. $this->getCleanText($node->nodeValue);
  }

  protected function formatAddress(DOMElement $node)
  {
    $type = $this->getNodeType($node);

    $entry  = 'ADR;CHARSET=UTF-8;'. $this->prefixType.$type .':;;'; // skip office & extended (toDo)
    $entry .= $node->getAttribute("street") .';';
    $entry .= $node->getAttribute("city") .';';
    $entry .= $node->getAttribute("region") .';';
    $entry .= $node->getAttribute("zip") .';';
    $entry .= $node->getAttribute("country");

    $entry .= PHP_EOL;

    $entry .= 'LABEL;CHARSET=UTF-8;'. $this->prefixType.$type .':';
    $entry .= $node->getAttribute("street") .'\n';
    $entry .= $node->getAttribute("city") .', ';
    $entry .= $node->getAttribute("region") .' ';
    $entry .= $node->getAttribute("zip") .'\n';
    $entry .= $node->getAttribute("country");

    $entry .= PHP_EOL;

    return $entry;
  }

  protected function formatPhone(DOMElement $node)
  {
    $entry  = 'TEL;'. $this->prefixType.$this->getNodeType($node) .':'; 
    $entry .= $node->getAttribute("prefix") .' '. $node->getAttribute("number") . PHP_EOL;

    return $entry;
  }

  protected function formatEmail(DOMElement $node)
  {
    $entry = '';
    $emails = $this->getCleanEmail($node);
    $type = $this->getNodeType($node);
    foreach ($emails as $mail) {
      $entry .= 'EMAIL;'. $this->prefixType.$type .';INTERNET:'. $mail .PHP_EOL;
    }

    return $entry;
  }

  protected function formatWebpage(DOMElement $node)
  {
    return 'URL;'. $this->prefixType.$this->getNodeType($node) .':'. $node->getAttribute("uri") .PHP_EOL;
  }

  protected function formatNote(DOMElement $node)
  {
    return 'NOTE;CHARSET=UTF-8;'. $this->getCleanText($node->nodeValue) .PHP_EOL;
  }

  protected function getNodeType(DOMElement $node)
  {
    return strtoupper( parent::getNodeType($node) );
  }

}
?>
