<?php
require_once 'sys/class.mywidget.php';

/**
 * A class for adding a table of contents widget.
 * @author Luis Leiva
 * @date 11 Dec 2010
 * @require class.mywidget.php
 */
class TOC extends MyWidget
{
  protected $category = "navigation";

  /** HTML list element type: "ul" (default) or "ol" */
  protected $listType;

  /** 
   * Constructor. 
   * @param $tocList  comma-separated list of items to build the menu from
   * @param $listType enclosing HTML list can be either "ul" (default) or "ol"
   */
  public function __construct($dom, $listType = "ul")
  {
    parent::__construct($dom);
    $this->listType = $listType;
  }

  protected function create()
  {
    $list = '<div id="widget-toc">';
    $sectiongroups = $this->sourceDOM->getElementsByTagName('sectiongroup');
    if (count($sectiongroups) > 0) {
      $list .= '<'.$this->listType.'>';
      foreach ($sectiongroups as $sectiongroup)
      {
        $list .= '<li>' . $sectiongroup->getAttribute("title");
        $sections = $sectiongroup->getElementsByTagName('section');
        if (count($sections) > 0) {
          // get max levels first
          $max = 0;
          foreach ($sections as $section) {
            $level = (int)$section->getAttribute("level");
            if ($level > $max) $max = $level;
          }
          if ($max > 0) {
            // now allocate levels
            $list .= '<'.$this->listType.'>';
            foreach ($sections as $section)
            {
              $level = (int)$section->getAttribute("level");
              $list .= '<li>' . $section->getAttribute("title");

              if ($level < $max) {
                $list .= '</'.$this->listType.'>';
              }
              else if ($level == $max) { 
                for ($i = $max; $i > 1; --$i) {
                  $list .= '</li></'.$this->listType.'>';
                }
                $list .= '</li>';
              }
            }
            $list .= '</'.$this->listType.'>';
          }
        }
        $list .= '</li>';
      }
      $list .= '</'.$this->listType.'>';
    }
    $list .= '</div><!-- end widget-toc -->';

    return $list;
  }

  public function placeIn($placement = "") 
  {
    $path = $this->getCategoryUrl();
    $this->sourceDOM->addDOMElement( '<link href="'.$path.'/styles.css" rel="stylesheet" type="text/css" />', $this->head );

    $place = empty($placement) ? $this->nav : $placement;
    $this->sourceDOM->addDOMElement( $this->create(), $place );
  }

}
?>
