<?php
require_once 'sys/class.mywidget.php';

/**
 * A class for adding social widgets.
 * @author Luis Leiva
 * @date 11 Dec 2010
 * @require class.mywidget.php
 */
abstract class Social extends MyWidget
{
  protected $category = "social";

  /** Widget theme (default, circles, denim, inside, or sketch). */
  public $theme = "default";

  /** Items icon size: 32 (default) or 48. */
  public $iconSize = 32;

  /** Items to include once properly configured. */
  public $stack = array();

  /** Choose either social-profiles or social-media. */
  protected $flavor;
  /** Allowed items. */
  protected $items;

  /** 
   * Constructor. Accepts optionally an array with name as keys and url and values; 
   * e.g., array( array("name"=>"youtube","url"=>"http://..."), array("name"=>"flickr","url"=>"http://...") )
   */
  public function __construct($dom, $items = null)
  {
    parent::__construct($dom);

    $this->items = $this->getAllowedItems();

    if (count($items) > 0) {
      foreach($items as $item) {
        $this->addItem($item['name'], $item['url']);
      }
    }
  }

  public function addItem($name, $url) 
  {
    $w = strtolower($name);
    if (in_array($w, $this->items)) {
      $this->stack[$name] = $url;
    }
  }

  protected function create() 
  {
    $path = $this->getCategoryUrl().'/'.$this->flavor.'/images/';
    // create HTML code
    $list = '<div id="widget-social">';
    foreach($this->stack as $name => $url) {
      $list .= '<a href="'.$url.'"><img src="'.$path.'/'.$this->theme.'/'.$this->getIconNamePattern($name).'" alt="'.$name.'" /></a>';
    }
    $list .= '</div><!-- end widget-social -->';

    return $list;
  }

  public function placeIn($place = "footer") 
  {
    $this->sourceDOM->addDOMElement( $this->create(), $place );
  }

  protected function getAllowedItems() 
  {
    $path = $this->getIconPath();
    if ($handle = opendir($path)) {
      while (false !== ($file = readdir($handle))) {
        if (is_file($path.$file)) { $list[] = $this->getIconName($file); }
      }
      closedir($handle);
    }
    sort($list);

    return array_unique($list);
  }

  // not implemented in base class
  abstract protected function getIconNamePattern($name);
  // not implemented in base class
  abstract protected function getIconName($name);
  // not implemented in base class
  abstract protected function getIconPath();

}
?>
